@@ -237,7 +237,7 @@ as perl itself. See L<http://dev.perl.org/licenses/>.
 =cut
 
 use vars qw( $VERSION );
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -469,7 +469,7 @@ sub as_xml {
 	my $class = ref $self; 
 	$class =~ s{^(.*)::(.)(.*)}{lc($2) . $3}e;
 
-	my $encoding = $opts{'encoding'} // 'UTF-8';
+	my $encoding = $opts{'encoding'} || 'UTF-8';
 
 	$output .= "<?xml version=\"1.0\" encoding=\"$encoding\"?>\n" if $opts{'xml_prolog'};
 
